# ABSESpy: 社会-生态系统多主体建模框架

![ABSES_banner](https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/CleanShot%202023-10-19%20at%2019.08.12@2x.png)

<div align="center"><p>
    <a href="https://github.com/SongshGeoLab/ABSESpy/releases/latest">
        <img alt="Latest release" src="https://img.shields.io/github/v/release/SongshGeoLab/ABSESpy?style=for-the-badge&logo=probot&color=C9CBFF&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/SongshGeoLab/ABSESpy/pulse">
        <img alt="Last commit" src="https://img.shields.io/github/last-commit/SongshGeoLab/ABSESpy?style=for-the-badge&logo=probot&color=8bd5ca&logoColor=D9E0EE&labelColor=302D41"/>
    </a>
    <a href="https://github.com/SongshGeoLab/ABSESpy/blob/main/LICENSE">
        <img alt="License" src="https://img.shields.io/github/license/SongshGeoLab/ABSESpy?style=for-the-badge&logo=probot&color=ee999f&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/SongshGeoLab/ABSESpy/stargazers">
        <img alt="Stars" src="https://img.shields.io/github/stars/SongshGeoLab/ABSESpy?style=for-the-badge&logo=probot&color=c69ff5&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/SongshGeoLab/ABSESpy/issues">
        <img alt="Issues" src="https://img.shields.io/github/issues/SongshGeoLab/ABSESpy?style=for-the-badge&logo=probot&color=F5E0DC&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/SongshGeoLab/ABSESpy">
        <img alt="Repo Size" src="https://img.shields.io/github/repo-size/SongshGeoLab/ABSESpy?color=%23DDB6F2&label=SIZE&logo=codesandbox&style=for-the-badge&logoColor=D9E0EE&labelColor=302D41" />
    </a>

<a href="https://twitter.com/intent/follow?screen_name=shuangsong11">
    <img alt="follow on Twitter" src="https://img.shields.io/twitter/follow/shuangsong11?style=for-the-badge&logo=twitter&color=8aadf3&logoColor=D9E0EE&labelColor=302D41" />
</a>

<!-- Website Badge -->
<a href="https://cv.songshgeo.com/">
    <img src="https://img.shields.io/badge/Website-SongshGeo-brightgreen.svg?style=for-the-badge&logo=twitter&color=8aadf3&logoColor=D9E0EE&labelColor=302D41" alt="github">
</a>

  <!-- <p align="center">
    <img src="https://stars.medv.io/SongshGeoLab/ABSESpy.svg", title="commits"/>
  </p> -->

---
Language: [English Readme] | [简体中文]

**[<kbd> <br> 安装 <br> </kbd>][Install]**
**[<kbd> <br> 指南 <br> </kbd>][Getting Started]**
**[<kbd> <br> 教程 <br> </kbd>][Tutorials]**
**[<kbd> <br> 贡献 <br> </kbd>][Contribute]**

</div>

`ABSESpy`是针对社会-生态系统（SES）研究开发的多主体建模（ABM）框架。作为`Python`语言下最受欢迎的ABM框架[Mesa]的扩展包，`ABSESpy`进一步增强了行动者（即主体）与模型其他组件，特别是网格状空间的交互。`ABSESpy`模块化和低耦合设计，改进了数据输入/输出系统，使用户能通过配置文件优雅地维护大型项目。`ABSESpy` 还能对齐模型'滴答'与日历时间，使其专门用于针对现实世界 SES 问题进行多主体建模。`ABSESpy` 的最终目标是成为处理人类活动影响下使用多主体模型分析变化世界的首选工具。

## 主要特性

<img src="https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/ABSESpy%20API.jpg" alt="ABSESpy API structure" style="max-width:400px;max-height:400px;width:auto;height:auto;">

- 🌍 用地理数据模拟社会-生态系统。
- 🤖 轻松管理和操控代理。
- 🕙 让你的模型与现实世界时间保持一致。
- 📁 使用配置文件处理复杂的模型参数。
- 🙋 还有更多...

## 向贡献者们致谢

<div align="center"><p>
<a href="https://github.com/SongshGeoLab/ABSESpy/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=SongshGeoLab/ABSESpy" />
</a>
</div>

  [Mesa]: https://github.com/projectmesa/mesa
  [Contribute]: https://absespy.github.io/ABSESpy/home/contribution/
  [Getting Started]: https://absespy.github.io/ABSESpy/home/get_started/
  [Install]: https://absespy.github.io/ABSESpy/home/Installation/
  [Tutorials]: https://absespy.github.io/ABSESpy/tutorial/tutorial/
  [简体中文]: README.zh-cn.md
  [English Readme]: README.md
